@@ -6,6 +6,10 @@ family_set_elliptical <- c(
   "gaussian", "t"
 )
 
+family_set_extreme_value <- c(
+  "tawn", "gumbel"
+)
+
 family_set_bb <- c(
   "bb1", "bb6", "bb7", "bb8"
 )
@@ -18,8 +22,12 @@ family_set_twopar <- c(
   "t", family_set_bb
 )
 
+family_set_threepar <- c(
+  "tawn"
+)
+
 family_set_parametric <- c(
-  "indep", family_set_onepar, family_set_twopar
+  "indep", family_set_onepar, family_set_twopar, family_set_threepar
 )
 
 family_set_nonparametric <- c(
@@ -39,8 +47,8 @@ family_set_all <- unique(
 )
 
 family_set_defs <- c(
-  "archimedean", "elliptical", "bbs", "oneparametric", "twoparametric",
-  "parametric", "nonparametric", "itau", "all"
+  "archimedean", "elliptical", "ev", "bbs", "oneparametric", "twoparametric",
+  "threeparametric", "parametric", "nonparametric", "itau", "all"
 )
 
 family_set_all_defs <- c(
